#
# spec file for package python3-sympy
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-sympy
Version:        0.7.6
Release:        6.5
Summary:        Python library for symbolic mathematics
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Url:            http://code.google.com/p/sympy/
Source0:        https://github.com/sympy/sympy/releases/download/sympy-%{version}/sympy-%{version}.tar.gz
BuildRequires:  python3-devel
#BuildRequires:  python3-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
SymPy is a Python library for symbolic mathematics. It aims to become
a full-featured computer algebra system (CAS) while keeping the code
as simple as possible in order to be comprehensible and easily
extensible. SymPy is written entirely in Python and does not require
any external libraries.

%prep
%setup -q -n sympy-%{version}
# For rpmlint warning: remove shebang from python library:
sed -i '/^#!/d' ./sympy/mpmath/tests/runtests.py

%build
python3 setup.py build

%install
python3 setup.py install --root=%{buildroot} --prefix=%{_prefix}
mv %{buildroot}%{_bindir}/isympy %{buildroot}%{_bindir}/isympy-%{py3_ver}
ln -s %{_bindir}/isympy-%{py3_ver} %{buildroot}%{_bindir}/isympy
mv %{buildroot}%{_mandir}/man1/isympy.1 %{buildroot}%{_mandir}/man1/isympy-%{py3_ver}.1
ln -s %{_mandir}/man1/isympy-%{py3_ver}.1 %{buildroot}%{_mandir}/man1/isympy.1

%pre
# Since /usr/bin/isympy and /usr/share/man/man1/isympy.1.gz became ghosted to be used
# with update-alternatives, we have to get rid of the old binary resulting from the
# non-update-alternativies-ified package:
[ -h %{_bindir}/isympy ] || rm -f %{_bindir}/isympy
[ -h %{_mandir}/man1/isympy.1.gz ] || rm -f %{_mandir}/man1/isympy.1.gz

%post
update-alternatives \
    --install %{_bindir}/isympy isympy %{_bindir}/isympy-%{py3_ver} 30 \
    --slave %{_mandir}/man1/isympy.1.gz isympy.1 %{_mandir}/man1/isympy-%{py3_ver}.1.gz

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove isympy %{_bindir}/isympy-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
%ghost %{_bindir}/isympy
%{_bindir}/isympy-%{py3_ver}
%ghost %{_mandir}/man1/isympy.1.gz
%{_mandir}/man1/isympy-%{py3_ver}.1.gz
%{python3_sitelib}/sympy
%{python3_sitelib}/sympy-%{version}-py%{py3_ver}.egg-info

%changelog
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * remove ifs for opensuse version <=1220
* Sat Nov 29 2014 arun@gmx.de
- update to version 0.7.6
  Major changes
  * New module "calculus.finite_diff" for generating finite difference
    formulae approximating derivatives of arbitrary order on arbitrarily
    spaced grids.
  * New module "physics.optics" for symbolic computations related to
    optics.
  * "geometry" module now supports 3D geometry.
  * Support for series expansions at a point other then 0 or oo.  See PR
    [#2427](https://github.com/sympy/sympy/pull/2427).
  * Rules for the intersection of integer ImageSets were added. See PR
    [#7587](https://github.com/sympy/sympy/pull/7587). We can now do
    things like `{2⋅m | m ∊ ℤ} ∩ {3⋅n | n ∊ ℤ} = {6⋅t | t ∊ ℤ}` and `{2⋅m
    | m ∊ ℤ} ∩ {2⋅n + 1 | n ∊ ℤ} = ∅ `
  * "dsolve" module now supports system of ODEs including linear
    system of ODEs of 1st order for 2 and 3 equations and of 2nd order
    for 2 equations. It also supports homogeneous linear system of `n`
    equations.
  * New support for continued fractions, including iterators for partial
    quotients and convergents, and reducing a continued fraction to a
    Rational or a quadratic irrational.
  * Support for Egyptian fraction expansions, using several different
    algorithms.
  * Addition of generalized linearization methods to
    'physics.mechanics'.
  * Use an LRU cache by default instead of an unbounded one. See PR
    [#7464] (https://github.com/sympy/sympy/pull/7464).  Control cache
    size by the environment variable 'SYMPY_CACHE_SIZE' (default is
    500).  'SYMPY_CACHE_SIZE=None' restores the unbounded cache.
  * Added 'fastcache' as an optional dependency.  Requires v0.4 or
    newer.  Control via 'SYMPY_CACHE_SIZE'.  May result in significant
    speedup. See PR [#7737] (https://github.com/sympy/sympy/pull/7737).
  * New experimental module 'physics.unitsystems' for computation with
    dimensions, units and quantities gathered into systems. This opens
    the way to dimensional analysis and better quantity calculus. The
    old module 'physics.units' will stay available until the new one
    reaches a mature state. See PR
    [#2628](https://github.com/sympy/sympy/pull/2628).
  * New 'Complement' class to represent relative complements of two
    sets. See Pr [#7462](https://github.com/sympy/sympy/pull/7462).
  * New trigonometric functions (asec, acsc), many enhancements for
    other trigonometric functions (PR
    [#7500](https://github.com/sympy/sympy/pull/7500)).
  * New 'Contains' class to represent the relation "is an element of"
    (see PR [#7989](https://github.com/sympy/sympy/pull/7989)).
  * The code generation tools (code printers, 'codegen', 'autowrap', and
    'ufuncify') have been updated to support a wider variety of
    constructs, and do so in a more robust way. Major changes include
    added support for matrices as inputs/outputs, and more robust
    handling of conditional ('Piecewise') statements.
  * 'ufuncify' now uses a backend that generates actual 'numpy.ufuncs'
    by default through the use of the 'numpy' C api. This allows
    broadcasting on *all* arguments. The previous 'cython' and 'f2py'
    backends are still accessible through the use of the 'backend'
    kwarg.
  * 'CodeGen' now generates code for Octave and Matlab from SymPy
    expressions.  This is supported by a new CodePrinter with interface
    'octave_code'.  For example 'octave_code(Matrix([[x**2, sin(pi*x*y),
    ceiling(x)]]))' gives the string '[x.^2 sin(pi*x.*y) ceil(x)]'.
  * New general 3D vector package at 'sympy.vector'. This package
    provides a 3D vector object with the Del, gradient, divergence,
    curl, and operators. It supports arbitrary rotations of Cartesian
    coordinate systems and arbitrary locations of points.
  Backwards compatibility breaks and deprecations
  * All usage of inequalities ('>', '>=', '<', '<=') on SymPy objects
    will now return SymPy's 'S.true' or 'S.false' singletons instead of
    Python's 'True' or 'False' singletons.  Code that checks for, e.g.,
    '(a < b) is True' should be changed to '(a < b) == True' or '(a < b)
    == S.true'.  Use of 'is' is not recommended here.
  * The 'subset()' method in 'sympy.core.sets' is marked as being
    deprecated and will be removed in a future release
    ([issue](https://github.com/sympy/sympy/issues/7460)). Instead, the
    'is_subset()' method should be used.
  * Previously, if you compute the series expansion at a point other
    than 0, the result was shifted to 0.  Now SymPy returns the usual
    series expansion, see PR
    [#2427](https://github.com/sympy/sympy/pull/2427).
  * In 'physics.mechanics', 'KanesMethod.linearize' has a new
    interface. Old code should be changed to use this instead. See
    docstring for information.
  * 'physics.gaussopt' has been moved to 'physics.optics.gaussopt'. You
    can still import it from the previous location but it may result in
    a deprecation warning.
  * This is the last release with the bundled [mpmath
    library](http://mpmath.org/). In the next release you will have to
    install this library from the official site.
  * Previously 'lambdify' would convert 'Matrix' to 'numpy.matrix' by
    default. This behavior is being deprecated, and will be completely
    phased out with the release of 0.7.7. To use the new behavior now
    set the modules kwarg to '[{'ImmutableMatrix': numpy.array},
    'numpy']'. If lambdify will be used frequently it is recommended to
    wrap it with a 'partial' as so: 'lambdify =
    functools.partial(lambdify, modules=[{'ImmutableMatrix':
    numpy.array}, 'numpy'])'. For more information see
    [#7853](https://github.com/sympy/sympy/issues/7853) and the
    'lambdify' doc string.
  * 'Set.complement' doesn't exists as an attribute anymore. Now we have
    a method 'Set.complement(<universal_set>)' which complements the
    given universal set.
  * Removed is_finite assumption (see
    [#7891](https://github.com/sympy/sympy/pull/7891)).  Use instead a
    combination of "is_bounded and is_nonzero" assumptions.
  * is_bounded and is_unbounded assumptions were renamed to is_finite
    and is_infinite (see
    [#7947](https://github.com/sympy/sympy/pull/7947)).
  * Removed is_infinitesimal assumption (see
    [#7995](https://github.com/sympy/sympy/pull/7995)).
  * Removed is_real property for Sets, use set.is_subset(Reals) instead
    (see [#7996](https://github.com/sympy/sympy/pull/7996)).
  * For generic symbol 'x' (SymPy's symbols are not bounded by default),
    inequalities with 'oo' are no longer evaluated as they were before,
    e.g. 'x < oo' no longer evaluates to True).  See
    [#7861](https://github.com/sympy/sympy/pull/7861).
  * 'CodeGen' has been refactored to make it easier to add other
    languages.  The main high-level tool is still
    'utilities.codegen.codegen'.  But if you previously used the
    'Routine' class directly, note its '__init__' behaviour has changed;
    the new 'utilities.codegen.make_routine' is recommended instead and
    by default retains the previous C/Fortran behaviour.  If needed, you
    can still instantiate 'Routine' directly; it only does minimal
    sanity checking on its inputs.  See
    [#8082](https://github.com/sympy/sympy/pull/8082).
  * 'FiniteSet([1, 2, 3, 4])' syntax not supported anymore, use
    'FiniteSet(1, 2, 3, 4)' instead See
    [#7622](https://github.com/sympy/sympy/pull/7622).
  Minor changes
  * Updated the parsing module to allow sympification of lambda
  * statements to their SymPy equivalent.  Lambdify can now use
  * 'numexpr' by specifying 'modules='numexpr'' Use 'with
  * evaluate(False)' context manager to control automatic evaluation.
  * E.g. 'with evaluate(False): x + x' is actually 'x + x', not '2*x'
  * IndexedBase and Indexed are changed to be commutative by default
  * 'sympy.core.sets' moved to 'sympy.sets' Changes in 'sympy.sets':
  * Infinite 'Range' is now allowed. See PR
  * [#7741](https://github.com/sympy/sympy/pull/7741) 'is_subset()': The
  * 'is_subset()' method deprecates the 'subset()' method.
  * 'self.is_subset(other)' checks if 'self' is a subset of
  * 'other'. This is different from 'self.subset(other)', which checked
  * if 'other' is a subset of 'self'.  'is_superset()': A new method
  * 'is_superset()' method is now available. 'self.is_superset(other)'
  * checks if 'self' is a superset of 'other'.  'is_proper_subset' and
  * 'is_proper_superset': Two new methods allow checking if one set is
  * the proper subset and proper superset of another respectively. For
  * eg. 'self.is_proper_subset(other)' and
  * 'self.is_proper_superset(other)' checks if 'self' is the proper
  * subset of 'other' and if 'self' is the proper superset of 'other'
  * respectively.  'is_disjoint()': A new method for checking if two
  * sets are disjoint.  'powerset()': A new method 'powerset()' has been
  * added to find the power set of a set.  The cardinality of a
  * 'ProductSet' can be found using the 'len()' function.  Changes in
  * 'sympy.plot.plot_implicit': The 'plot_implicit' function now also
  * allows explicitly specifying the symbols to plot on the X and Y
  * axes. If not specified, the symbols will be assigned in the order
  * they are sorted.  The 'plot_implicit' function also allows axes
  * labels for the plot to be specified.  rules for simplification of
  * ImageSet were added
  * PR[#7625](https://github.com/sympy/sympy/pull/7625). As a result '{x
  * | x ∊ ℤ}' now simplifies to 'ℤ' and '{sin(n) | n ∊ {tan(m) | m ∊
  * ℤ}}' automatically simplifies to '{sin(tan(m)) | m ∊ ℤ}' coth(0) now
  * returns Complex Infinity. See
  * [#7634](https://github.com/sympy/sympy/pull/7634) dioptre is added
  * to 'physics.units' [#7782](https://github.com/sympy/sympy/pull/7782)
  * 'replace' now respects commutativity
  * [#7752](https://github.com/sympy/sympy/pull/7752) The CCodePrinter
  * gracefully handles Symbols which have string representations that
  * match C reserved
  * words. [#8199](https://github.com/sympy/sympy/pull/8199) 'limit'
  * function now returns an unevaluated Limit instance if it can't
  * compute given limit, see
  * [#8213](https://github.com/sympy/sympy/pull/8213)
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Fri Mar  7 2014 arun@gmx.de
- update to version 0.7.5
  Major changes:
  * The version of mpmath included in SymPy has been updated to 0.18.
  * New routines for efficiently compute the dispersion of a polynomial or a pair thereof.
  * Fancy indexing of matrices is now provided, e.g. A[:, [1, 2, 5]] selects all rows and only 3 columns.
  * Enumeration of multiset partitions is now based on an
    implementation of Algorithm 7.1.2.5M from Knuth's The Art of
    Computer Programming. The new version is much faster, and includes
    fast methods for enumerating only those partitions with a
    restricted range of sizes, and counting multiset partitions. (See
    the new file sympy.utilities.enumerative.py.)
  * distance methods were added to Line and Ray to compute the shortest distance to them from a point.
  * The normal_lines method was added to Ellipse to compute the lines from a point that strike the Ellipse at a normal angle.
  * inv_quick and det_quick were added as functions in solvers.py to
    facilitate fast solution of small symbolic matrices; their use in
    solve has reduced greatly the time needed to solve such systems.
  * solve_univariate_inequality has been added to sympy.solvers.inequalities.py.
  * as_set attribute for Relationals and Booleans has been added.
  * Several classes and functions strictly associated with vector
    calculus were moved from sympy.physics.mechanics to a new package
    sympy.physics.vector. (PRs #2732 #2862 #2894)
  * New implementation of the Airy functions Ai and Bi and their
    derivatives Ai' and Bi' (called airyai, airybi, airyaiprime and
    airybiprime, respectively). Most of the usual features of SymPy
    special function are present. Notable exceptions are Gruntz limit
    computation helpers and meijerg special functions integration
    code.
  * Euler-Lagrange equations (function euler_equations) in a new package sympy.calculus (PR #2431).
  Minor changes:
  * Some improvements to the gamma function.
  * generate_bell now generates correct permutations for any number of elements.
  * It is no longer necessary to provide nargs to objects subclassed
    from Function unless an eval class method is not defined. (If eval
    is defined, the number of arguments will be inferred from its
    signature.)
  * geometric Point creation will be faster since simplification is done only on Floats
  * Some improvements to the intersection method of the Ellipse.
  * solutions from solve of equations involving multiple log terms are more robust
  * idiff can now return higher order derivatives
  * Added to_matrix() method to sympy.physics.vector.Vector and
    sympy.physics.dyadic.Dyadic. (PR #2686).
  * Printing improvements for sympy.physics.vector objects and
    mechanics printing. (PRs #2687, #2728, #2772, #2862, #2894)
  * Functions with LaTeX symbols now print correct LaTeX. (PR #2772)
  * init_printing has several new options, including a flag
    print_builtin to prevent SymPy printing of basic Python types (PR
    [#2683]), and flags to let you supply custom printers (PR #2894).
  * improvements in evaluation of imageset for Intervals (PR #2723).
  * Set properties to determine boundary and interior (PR #2744).
  * input to a function created by lambdify no longer needs to be flattened.
  Backwards compatibility breaks and deprecations:
  * the submatrix method of matrices was removed; access the
    functionality by providing slices or list of rows/columns to
    matrix directly, e.g. A[:, [1, 2]].
  * Matrix([]) and Matrix([[]]) now both return a 0x0 matrix
  * terms_gcd no longer removes a -1.0 from expressions
  * extract_multiplicatively will not remove a negative Number from a
    positive one, so (4*x*y).extract_multiplicatively(-2*x) will
    return None.
  * the shape of the result from M.cross(B) now has the same shape as matrix M.
  * The factorial of negative numbers is now zoo instead of 0. This is
    consistent with the definition factorial(n) = gamma(n + 1).
  * 1/0 returns zoo, not oo (PR #2813).
  * zoo.is_number is True (PR #2823).
  * oo < I raises TypeError, just as for finite numbers (PR #2734).
  * 1**oo == nan instead of 1, better documentation for Pow class (PR #2606).
* Sat Jan 11 2014 arun@gmx.de
- update to 0.7.4.1
  * This was a small bugfix release to fix an import issue on Windows (https://github.com/sympy/sympy/issues/2681).
- update to 0.7.4 (see https://github.com/sympy/sympy/wiki/Release-Notes-for-0.7.4)
* Thu Dec  5 2013 speilicke@suse.com
- Package LICENSE and README.rst
* Wed Oct 23 2013 toddrme2178@gmail.com
- Add BuildRequires: python3 for openSUSE 12.2, so hashlib is
  available.
* Thu Sep 26 2013 speilicke@suse.com
- Update to version 0.7.3:
  + See https://github.com/sympy/sympy/wiki/Release-Notes-for-0.7.3
- Use update-alternatives for binaries / man-pages
* Mon Jan 28 2013 saschpe@suse.de
- Don't use URL in Source: the tarball does not exist there. Otherwise,
  ractory-auto fail trying to download it
* Tue Jan 15 2013 p.drouand@gmail.com
- Initial python3 support
